@@ -100,6 +100,7 @@ abstract class num implements Comparable<num> {
    * print(double.infinity < double.nan);  // => false
    * print(double.nan < double.infinity);  // => false
    * print(double.nan == double.infinity);  // => false
+   * ```
    */
   int compareTo(num other);
 
@@ -358,8 +359,8 @@ abstract class num implements Comparable<num> {
    *     1.toStringAsFixed(3);  // 1.000
    *     (4321.12345678).toStringAsFixed(3);  // 4321.123
    *     (4321.12345678).toStringAsFixed(5);  // 4321.12346
-   *     123456789012345678901.toStringAsFixed(3);  // 123456789012345683968.000
-   *     1000000000000000000000.toStringAsFixed(3); // 1e+21
+   *     123456789012345.toStringAsFixed(3);  // 123456789012345.000
+   *     10000000000000000.toStringAsFixed(4); // 10000000000000000.0000
    *     5.25.toStringAsFixed(0); // 5
    */
   String toStringAsFixed(int fractionDigits);
@@ -384,7 +385,7 @@ abstract class num implements Comparable<num> {
    *     123456.toStringAsExponential(3); // 1.235e+5
    *     123.toStringAsExponential(0);    // 1e+2
    */
-  String toStringAsExponential([int fractionDigits]);
+  String toStringAsExponential([int? fractionDigits]);
 
   /**
    * Converts `this` to a double and returns a string representation with
@@ -467,10 +468,10 @@ abstract class num implements Comparable<num> {
    * Instead of `num.parse(string, (string) { ... })`,
    * you should use `num.tryParse(string) ?? (...)`.
    */
-  static num parse(String input, [@deprecated num onError(String input)]) {
-    num result = tryParse(input);
+  static num parse(String input, [@deprecated num onError(String input)?]) {
+    num? result = tryParse(input);
     if (result != null) return result;
-    if (onError == null) throw new FormatException(input);
+    if (onError == null) throw FormatException(input);
     return onError(input);
   }
 
@@ -480,13 +481,9 @@ abstract class num implements Comparable<num> {
    * Like [parse] except that this function returns `null` for invalid inputs
    * instead of throwing.
    */
-  static num tryParse(String input) {
+  static num? tryParse(String input) {
     String source = input.trim();
     // TODO(lrn): Optimize to detect format and result type in one check.
     return int.tryParse(source) ?? double.tryParse(source);
   }
-
-  /** Helper functions for [parse]. */
-  static int _returnIntNull(String _) => null;
-  static double _returnDoubleNull(String _) => null;
 }
